@@ -1,4 +1,4 @@
-/* $Id: dict.c,v 1.25 2005/02/11 16:52:44 vnoel Exp $ */
+/* $Id: dict.c,v 1.28 2005/12/02 16:50:29 vnoel Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -185,8 +185,9 @@ cycle_buffer (dict_context_t *context)
 static char *dict_read_line (dict_context_t *context) {
     char *start_ptr, *end_ptr;
     
-    if (!context->channel) return NULL;
-   
+    if (context->channel == NULL) return NULL;
+    if (context->read_ptr == NULL || *context->read_ptr == '0') return NULL;
+
     while (1) {
         end_ptr = strchr (context->read_ptr, '\r');
         
@@ -277,6 +278,9 @@ static void data_notify_match (dict_context_t *context, char *line)
         else {
             word = line;
             
+	    if (line == NULL)
+	      break;
+
             line = strchr (line, ' ');
             *line = '\0'; line++;
             if (*line == '\"') line++;
@@ -461,6 +465,9 @@ static void data_notify_show_db (dict_context_t *context, char *line)
         }
         else {
             name = line;
+	    if (line == NULL)
+	      break;
+
             line = strchr (line, ' ');
             *line = '\0'; line++;
             if (*line == '\"') line++;
@@ -548,8 +555,12 @@ static void data_notify_show_strat (dict_context_t *context,
             command->state = S_STATUS;
         }
         else {
+	    if (line == NULL)
+	      break;
+
 	    newline = line = g_strdup (line);
             name = line;
+
             line = strchr (line, ' ');
             *line = '\0'; line++;
             if (*line == '\"') line++;
@@ -687,7 +698,7 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
 						     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
 						     "<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
 						     _("Server Error"),
-						     _("A serious error occured. Please check that your server and port are correct. For reference the default server is dict.org and the port 2628"));
+						     _("A serious error occurred. Please check that your server and port are correct. For reference the default server is dict.org and the port 2628"));
         g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
                                   G_CALLBACK (gtk_widget_destroy),
                                   GTK_OBJECT (dialog));
@@ -769,9 +780,16 @@ void dict_context_destroy (dict_context_t *context)
     dict_disconnect (context);
     g_free (context->hostname);
     context->hostname = NULL;
+
+    if (context->command != NULL) {
+      g_free (context->command);
+    }
+
     /* FOOOOOOOO, HAAAAAAAAAAACK, the notify handler still gets called,
      * I do not understand this, this keeps it from dieing */
     /*g_free (context);*/
+    /* FIXME: Are these hacks still necessary? */
+    g_free (context);
 }
 
 /* dict_connect (context)
